import { Component, ComponentFactoryResolver, Directive, ElementRef, Input, NgModule, Renderer2, ViewChild, ViewContainerRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';
var SlideZoneDirective = /** @class */ (function () {
    /**
     * @param {?} viewContainerRef
     */
    function SlideZoneDirective(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
    return SlideZoneDirective;
}());
SlideZoneDirective.decorators = [
    { type: Directive, args: [{
                selector: '[slideZone]'
            },] },
];
/**
 * @nocollapse
 */
SlideZoneDirective.ctorParameters = function () { return [
    { type: ViewContainerRef, },
]; };
var CarouselSlideComponent = /** @class */ (function () {
    /**
     * @param {?} el
     * @param {?} renderer
     */
    function CarouselSlideComponent(el, renderer) {
        this.el = el;
        this.renderer = renderer;
    }
    /**
     * @param {?} offset
     * @return {?}
     */
    CarouselSlideComponent.prototype.slide = function (offset) {
        this.renderer.addClass(this.el.nativeElement, 'delay');
        this.renderer.setStyle(this.el.nativeElement, 'transform', 'translate3d(' + offset + 'px, 0, 0)');
    };
    /**
     * @param {?} offset
     * @return {?}
     */
    CarouselSlideComponent.prototype.stabilizes = function (offset) {
        this.renderer.removeClass(this.el.nativeElement, 'delay');
        this.renderer.setStyle(this.el.nativeElement, 'transform', 'translate3d(' + offset + 'px, 0, 0)');
    };
    return CarouselSlideComponent;
}());
CarouselSlideComponent.decorators = [
    { type: Component, args: [{
                selector: 'pac-carousel-slide',
                template: "\n      <ng-container *ngIf=\"!route \">\n          <a [href]=\"link?link:'#'\">\n              <img [src]=\"src\">\n          </a>\n      </ng-container>\n\n      <ng-container *ngIf=\"route\">\n          <a [routerLink]=\"route\">\n              <img [src]=\"src\">\n          </a>\n      </ng-container>\n    ",
                styles: ["\n      :host {\n          max-width: 100%;\n          width: 100%;\n          height: 100%;\n          display: inline-table;\n          overflow: hidden;\n          -webkit-box-flex: 1;\n              -ms-flex: 1;\n                  flex: 1;\n          text-transform: uppercase;\n          position: relative;\n          cursor: pointer;\n          -ms-flex-align: end;\n          -webkit-box-align: end;\n                  align-items: flex-end;\n          -ms-flex-line-pack: end;\n          align-content: flex-end;\n      }\n\n      :host img {\n          width: 100%;\n      }\n\n      :host.delay {\n          -webkit-transition: transform .7s ease-in-out;\n          -webkit-transition: -webkit-transform .7s ease-in-out;\n          transition: -webkit-transform .7s ease-in-out;\n          transition: transform .7s ease-in-out;\n          transition: transform .7s ease-in-out, -webkit-transform .7s ease-in-out;\n          /*by nea adi*/\n      }\n    "]
            },] },
];
/**
 * @nocollapse
 */
CarouselSlideComponent.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
]; };
CarouselSlideComponent.propDecorators = {
    'src': [{ type: Input },],
    'link': [{ type: Input },],
    'route': [{ type: Input },],
};
var STATE_AVAILABLE = 'available';
var STATE_IDLE = 'idle';
var CarouselComponent = /** @class */ (function () {
    /**
     * @param {?} componentFactoryResolver
     */
    function CarouselComponent(componentFactoryResolver) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.autoPlay = true;
        this.time = 4;
        this.slides = [];
        this.carouselSlides = [];
        this.state = STATE_AVAILABLE;
        this.lastOffset = 0;
        this.index = 0;
    }
    /**
     * @return {?}
     */
    CarouselComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        this.viewContainerRef = this.slideZone.viewContainerRef;
        this.slides.forEach(function (slide) {
            var /** @type {?} */ componentFactory = _this.componentFactoryResolver.resolveComponentFactory(CarouselSlideComponent);
            var /** @type {?} */ componentRef = _this.viewContainerRef.createComponent(componentFactory);
            componentRef.instance.src = slide.src;
            componentRef.instance.route = slide.route;
            componentRef.instance.link = slide.link;
            _this.carouselSlides.push(componentRef.instance);
        });
        if (this.autoPlay) {
            this.interval = setInterval(function () {
                if (!_this.pause) {
                    _this.slideForward();
                }
            }, this.time * 1000);
        }
    };
    /**
     * @return {?}
     */
    CarouselComponent.prototype.ngOnDestroy = function () {
        if (this.interval) {
            clearInterval(this.interval);
        }
    };
    /**
     * @param {?} slide
     * @return {?}
     */
    CarouselComponent.prototype.addSlideData = function (slide) {
        this.slides.push(slide);
    };
    /**
     * @param {?} slide
     * @return {?}
     */
    CarouselComponent.prototype.removeSlide = function (slide) {
    };
    /**
     * @return {?}
     */
    CarouselComponent.prototype.pauseAutoPlay = function () {
        this.pause = true;
    };
    /**
     * @return {?}
     */
    CarouselComponent.prototype.startAutoPlay = function () {
        this.pause = false;
    };
    /**
     * @return {?}
     */
    CarouselComponent.prototype.slideBack = function () {
        var _this = this;
        if (this.state === STATE_AVAILABLE) {
            this.state = STATE_IDLE;
            var /** @type {?} */ ref = this.viewContainerRef.get(this.carouselSlides.length - 1);
            this.viewContainerRef.move(ref, 0);
            this.lastOffset -= this.sliderContainer.nativeElement.getBoundingClientRect().width;
            this.carouselSlides.forEach(function (slide) {
                slide.stabilizes(_this.lastOffset);
            });
            this.lastOffset += this.sliderContainer.nativeElement.getBoundingClientRect().width;
            this.carouselSlides.forEach(function (slide) {
                slide.slide(_this.lastOffset);
            });
            setTimeout(function () {
                _this.state = STATE_AVAILABLE;
                _this.index--;
                if (_this.index < 0) {
                    _this.index = _this.slides.length - 1;
                }
            }, 720);
            setTimeout(function () {
                _this.pause = false;
            }, this.time * 1000);
        }
    };
    /**
     * @return {?}
     */
    CarouselComponent.prototype.slideForward = function () {
        var _this = this;
        if (this.state === STATE_AVAILABLE) {
            this.state = STATE_IDLE;
            this.lastOffset -= this.sliderContainer.nativeElement.getBoundingClientRect().width;
            this.carouselSlides.forEach(function (slide) {
                slide.slide(_this.lastOffset);
            });
            setTimeout(function () {
                var /** @type {?} */ ref = _this.viewContainerRef.get(0);
                _this.viewContainerRef.move(ref, _this.carouselSlides.length - 1);
                _this.lastOffset = 0;
                _this.carouselSlides.forEach(function (slide) {
                    slide.stabilizes(_this.lastOffset);
                });
                _this.state = STATE_AVAILABLE;
                _this.index++;
                if (_this.index > _this.slides.length - 1) {
                    _this.index = 0;
                }
            }, 720);
        }
    };
    /**
     * @param {?} index
     * @return {?}
     */
    CarouselComponent.prototype.slideToIndex = function (index) {
        if (index > this.index) {
            this.slideForward();
        }
        else if (index < this.index) {
            this.slideBack();
        }
    };
    return CarouselComponent;
}());
CarouselComponent.decorators = [
    { type: Component, args: [{
                selector: 'pac-slider',
                template: "\n      <div class=\"carousel-container\" #sliderContainer>\n          <div class=\"arrow left-arrow\" (click)=\"slideBack()\" (mouseenter)=\"pauseAutoPlay()\">\n              <img src=\"assets/img/buttons/arrow-left-v2.svg\">\n          </div>\n          <div class=\"slides-zone\" #slidesZone>\n              <ng-content></ng-content>\n              <div class=\"images-container\" (mouseenter)=\"pauseAutoPlay()\" (mouseleave)=\"startAutoPlay()\" #slideImg>\n                  <ng-template slideZone>\n\n                  </ng-template>\n              </div>\n\n          </div>\n          <div class=\"dots-container\">\n              <ul (mouseenter)=\"pauseAutoPlay()\" (mouseleave)=\"startAutoPlay()\">\n                  <li *ngFor=\"let dot of slides;let i = index;\" (click)=\"slideToIndex(i)\" [ngClass]=\"{selected: i == index}\">\n                      <img src=\"assets/img/buttons/dot.svg\" alt=\"dot\">\n                  </li>\n              </ul>\n          </div>\n          <div class=\"arrow right-arrow\" (click)=\"slideForward()\" (mouseenter)=\"pauseAutoPlay()\">\n              <img src=\"assets/img/buttons/arrow-right-v2.svg\">\n          </div>\n      </div>\n    ",
                styles: ["\n      .carousel-container {\n          width: 100%;\n          max-height: 100vh;\n          overflow: hidden;\n          position: relative;\n\n      }\n\n      .images-container {\n          width: 100%;\n          display: -ms-flexbox;\n          display: -webkit-box;\n          display: flex;\n          -ms-flex: 1;\n          -webkit-box-flex: 1;\n                  flex: 1;\n          -ms-flex-align: center;\n          -webkit-box-align: center;\n                  align-items: center;\n          -ms-flex-pack: start;\n          -webkit-box-pack: start;\n                  justify-content: flex-start;\n          -webkit-transition: all 300ms cubic-bezier(0.35, 0, 0.25, 1);\n          transition: all 300ms cubic-bezier(0.35, 0, 0.25, 1);\n      }\n\n      .carousel-container .arrow {\n          z-index: 2;\n          position: absolute;\n          top: 0;\n          height: 100%;\n          width: 4%;\n          display: -ms-flexbox;\n          display: -webkit-box;\n          display: flex;\n          -ms-flex-direction: row;\n          -webkit-box-orient: horizontal;\n          -webkit-box-direction: normal;\n                  flex-direction: row;\n          -ms-flex-wrap: nowrap;\n          flex-wrap: nowrap;\n          -ms-flex-pack: center;\n          -webkit-box-pack: center;\n                  justify-content: center;\n          -ms-flex-line-pack: stretch;\n          align-content: stretch;\n          -ms-flex-align: center;\n          -webkit-box-align: center;\n                  align-items: center;\n\n      }\n\n      .carousel-container .arrow img {\n          width: 100%;\n          -ms-flex-order: 0;\n          -webkit-box-ordinal-group: 1;\n                  order: 0;\n          -ms-flex: 0 1 auto;\n          -webkit-box-flex: 0;\n                  flex: 0 1 auto;\n          -webkit-align-self: auto;\n          -ms-flex-item-align: auto;\n          align-self: auto;\n      }\n\n      .carousel-container .left-arrow {\n          -webkit-transition: all .6s ease-out;\n          transition: all .6s ease-out;\n          left: 0;\n          cursor: pointer;\n      }\n\n      .carousel-container .right-arrow {\n          right: 0;\n          cursor: pointer;\n      }\n\n      /*\n      .carousel-container .left-arrow:hover {\n      \tbackground: -moz-linear-gradient(left, rgba(0, 0, 0, 0.65) 0%, rgba(0, 0, 0, 0) 100%); !* FF3.6-15 *!\n      \tbackground: -webkit-linear-gradient(left, rgba(0, 0, 0, 0.65) 0%, rgba(0, 0, 0, 0) 100%); !* Chrome10-25,Safari5.1-6 *!\n      \tbackground: linear-gradient(to right, rgba(0, 0, 0, 0.65) 0%, rgba(0, 0, 0, 0) 100%); !* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ *!\n      \tfilter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#a6000000', endColorstr='#00000000', GradientType=1); !* IE6-9 *!\n      }\n\n      .carousel-container .right-arrow:hover {\n      \tbackground: -moz-linear-gradient(left, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.65) 100%); !* FF3.6-15 *!\n      \tbackground: -webkit-linear-gradient(left, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.65) 100%); !* Chrome10-25,Safari5.1-6 *!\n      \tbackground: linear-gradient(to right, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.65) 100%); !* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ *!\n      \tfilter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#a6000000', GradientType=1); !* IE6-9 *!\n      }*/\n\n      .carousel-container .dots-container {\n          z-index: 2;\n          position: absolute;\n          bottom: 0;\n          height: 10%;\n          width: 100%;\n          display: -ms-flexbox;\n          display: -webkit-box;\n          display: flex;\n          -ms-flex-direction: row;\n          -webkit-box-orient: horizontal;\n          -webkit-box-direction: normal;\n                  flex-direction: row;\n          -ms-flex-wrap: nowrap;\n          flex-wrap: nowrap;\n          -ms-flex-pack: center;\n          -webkit-box-pack: center;\n                  justify-content: center;\n          -ms-flex-line-pack: stretch;\n          align-content: stretch;\n          -ms-flex-align: center;\n          -webkit-box-align: center;\n                  align-items: center;\n      }\n\n      .carousel-container .dots-container ul {\n          list-style-type: none;\n          margin: 0;\n          padding: 0;\n          overflow: hidden;\n      }\n\n      .carousel-container .dots-container ul li {\n          display: inline;\n      }\n\n      .carousel-container .dots-container ul li img {\n          width: 10px;\n          padding: 5px;\n      }\n\n      .carousel-container .dots-container img {\n          cursor: pointer;\n          height: 10%;\n          width: 100%;\n          -ms-flex-order: 0;\n          -webkit-box-ordinal-group: 1;\n                  order: 0;\n          -ms-flex: 0 1 auto;\n          -webkit-box-flex: 0;\n                  flex: 0 1 auto;\n          -webkit-align-self: auto;\n          -ms-flex-item-align: auto;\n          align-self: auto;\n          opacity: .5;\n          /*transition: all .7s ease-out;*/\n      }\n\n      .carousel-container .dots-container li.selected img {\n          opacity: 1;\n      }\n    "]
            },] },
];
/**
 * @nocollapse
 */
CarouselComponent.ctorParameters = function () { return [
    { type: ComponentFactoryResolver, },
]; };
CarouselComponent.propDecorators = {
    'autoPlay': [{ type: Input },],
    'time': [{ type: Input },],
    'slidesZone': [{ type: ViewChild, args: ['slidesZone',] },],
    'sliderContainer': [{ type: ViewChild, args: ['sliderContainer',] },],
    'slideZone': [{ type: ViewChild, args: [SlideZoneDirective,] },],
};
var CarouselItemComponent = /** @class */ (function () {
    /**
     * @param {?} parent
     */
    function CarouselItemComponent(parent) {
        this.parent = parent;
        parent.addSlideData(this);
    }
    /**
     * @return {?}
     */
    CarouselItemComponent.prototype.ngOnInit = function () {
    };
    /**
     * @return {?}
     */
    CarouselItemComponent.prototype.ngOnDestroy = function () {
        this.parent.removeSlide(this);
    };
    return CarouselItemComponent;
}());
CarouselItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'pac-item',
                template: "\n\n    ",
                styles: ["\n\n    "]
            },] },
];
/**
 * @nocollapse
 */
CarouselItemComponent.ctorParameters = function () { return [
    { type: CarouselComponent, },
]; };
CarouselItemComponent.propDecorators = {
    'src': [{ type: Input },],
    'link': [{ type: Input },],
    'route': [{ type: Input },],
};
var PacSliderModule = /** @class */ (function () {
    function PacSliderModule() {
    }
    return PacSliderModule;
}());
PacSliderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    RouterModule
                ],
                declarations: [CarouselComponent, CarouselItemComponent, CarouselSlideComponent, SlideZoneDirective],
                entryComponents: [CarouselSlideComponent],
                exports: [CarouselComponent, CarouselItemComponent]
            },] },
];
/**
 * @nocollapse
 */
PacSliderModule.ctorParameters = function () { return []; };
/**
 * Generated bundle index. Do not edit.
 */
export { PacSliderModule, CarouselItemComponent as ɵc, CarouselSlideComponent as ɵd, CarouselComponent as ɵa, SlideZoneDirective as ɵb };
//# sourceMappingURL=pac-slider.es5.js.map
