import { Component, ComponentFactoryResolver, Directive, ElementRef, Input, NgModule, Renderer2, ViewChild, ViewContainerRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule } from '@angular/router';

class SlideZoneDirective {
    /**
     * @param {?} viewContainerRef
     */
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
}
SlideZoneDirective.decorators = [
    { type: Directive, args: [{
                selector: '[slideZone]'
            },] },
];
/**
 * @nocollapse
 */
SlideZoneDirective.ctorParameters = () => [
    { type: ViewContainerRef, },
];

class CarouselSlideComponent {
    /**
     * @param {?} el
     * @param {?} renderer
     */
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
    }
    /**
     * @param {?} offset
     * @return {?}
     */
    slide(offset) {
        this.renderer.addClass(this.el.nativeElement, 'delay');
        this.renderer.setStyle(this.el.nativeElement, 'transform', 'translate3d(' + offset + 'px, 0, 0)');
    }
    /**
     * @param {?} offset
     * @return {?}
     */
    stabilizes(offset) {
        this.renderer.removeClass(this.el.nativeElement, 'delay');
        this.renderer.setStyle(this.el.nativeElement, 'transform', 'translate3d(' + offset + 'px, 0, 0)');
    }
}
CarouselSlideComponent.decorators = [
    { type: Component, args: [{
                selector: 'pac-carousel-slide',
                template: `
      <ng-container *ngIf="!route ">
          <a [href]="link?link:'#'">
              <img [src]="src">
          </a>
      </ng-container>

      <ng-container *ngIf="route">
          <a [routerLink]="route">
              <img [src]="src">
          </a>
      </ng-container>
    `,
                styles: [`
      :host {
          max-width: 100%;
          width: 100%;
          height: 100%;
          display: inline-table;
          overflow: hidden;
          -webkit-box-flex: 1;
              -ms-flex: 1;
                  flex: 1;
          text-transform: uppercase;
          position: relative;
          cursor: pointer;
          -ms-flex-align: end;
          -webkit-box-align: end;
                  align-items: flex-end;
          -ms-flex-line-pack: end;
          align-content: flex-end;
      }

      :host img {
          width: 100%;
      }

      :host.delay {
          -webkit-transition: transform .7s ease-in-out;
          -webkit-transition: -webkit-transform .7s ease-in-out;
          transition: -webkit-transform .7s ease-in-out;
          transition: transform .7s ease-in-out;
          transition: transform .7s ease-in-out, -webkit-transform .7s ease-in-out;
          /*by nea adi*/
      }
    `]
            },] },
];
/**
 * @nocollapse
 */
CarouselSlideComponent.ctorParameters = () => [
    { type: ElementRef, },
    { type: Renderer2, },
];
CarouselSlideComponent.propDecorators = {
    'src': [{ type: Input },],
    'link': [{ type: Input },],
    'route': [{ type: Input },],
};

const STATE_AVAILABLE = 'available';
const STATE_IDLE = 'idle';
class CarouselComponent {
    /**
     * @param {?} componentFactoryResolver
     */
    constructor(componentFactoryResolver) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.autoPlay = true;
        this.time = 4;
        this.slides = [];
        this.carouselSlides = [];
        this.state = STATE_AVAILABLE;
        this.lastOffset = 0;
        this.index = 0;
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.viewContainerRef = this.slideZone.viewContainerRef;
        this.slides.forEach(slide => {
            let /** @type {?} */ componentFactory = this.componentFactoryResolver.resolveComponentFactory(CarouselSlideComponent);
            let /** @type {?} */ componentRef = this.viewContainerRef.createComponent(componentFactory);
            componentRef.instance.src = slide.src;
            componentRef.instance.route = slide.route;
            componentRef.instance.link = slide.link;
            this.carouselSlides.push(componentRef.instance);
        });
        if (this.autoPlay) {
            this.interval = setInterval(() => {
                if (!this.pause) {
                    this.slideForward();
                }
            }, this.time * 1000);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.interval) {
            clearInterval(this.interval);
        }
    }
    /**
     * @param {?} slide
     * @return {?}
     */
    addSlideData(slide) {
        this.slides.push(slide);
    }
    /**
     * @param {?} slide
     * @return {?}
     */
    removeSlide(slide) {
    }
    /**
     * @return {?}
     */
    pauseAutoPlay() {
        this.pause = true;
    }
    /**
     * @return {?}
     */
    startAutoPlay() {
        this.pause = false;
    }
    /**
     * @return {?}
     */
    slideBack() {
        if (this.state === STATE_AVAILABLE) {
            this.state = STATE_IDLE;
            let /** @type {?} */ ref = this.viewContainerRef.get(this.carouselSlides.length - 1);
            this.viewContainerRef.move(ref, 0);
            this.lastOffset -= this.sliderContainer.nativeElement.getBoundingClientRect().width;
            this.carouselSlides.forEach((slide) => {
                slide.stabilizes(this.lastOffset);
            });
            this.lastOffset += this.sliderContainer.nativeElement.getBoundingClientRect().width;
            this.carouselSlides.forEach((slide) => {
                slide.slide(this.lastOffset);
            });
            setTimeout(() => {
                this.state = STATE_AVAILABLE;
                this.index--;
                if (this.index < 0) {
                    this.index = this.slides.length - 1;
                }
            }, 720);
            setTimeout(() => {
                this.pause = false;
            }, this.time * 1000);
        }
    }
    /**
     * @return {?}
     */
    slideForward() {
        if (this.state === STATE_AVAILABLE) {
            this.state = STATE_IDLE;
            this.lastOffset -= this.sliderContainer.nativeElement.getBoundingClientRect().width;
            this.carouselSlides.forEach((slide) => {
                slide.slide(this.lastOffset);
            });
            setTimeout(() => {
                let /** @type {?} */ ref = this.viewContainerRef.get(0);
                this.viewContainerRef.move(ref, this.carouselSlides.length - 1);
                this.lastOffset = 0;
                this.carouselSlides.forEach((slide) => {
                    slide.stabilizes(this.lastOffset);
                });
                this.state = STATE_AVAILABLE;
                this.index++;
                if (this.index > this.slides.length - 1) {
                    this.index = 0;
                }
            }, 720);
        }
    }
    /**
     * @param {?} index
     * @return {?}
     */
    slideToIndex(index) {
        if (index > this.index) {
            this.slideForward();
        }
        else if (index < this.index) {
            this.slideBack();
        }
    }
}
CarouselComponent.decorators = [
    { type: Component, args: [{
                selector: 'pac-slider',
                template: `
      <div class="carousel-container" #sliderContainer>
          <div class="arrow left-arrow" (click)="slideBack()" (mouseenter)="pauseAutoPlay()">
              <img src="assets/img/buttons/arrow-left-v2.svg">
          </div>
          <div class="slides-zone" #slidesZone>
              <ng-content></ng-content>
              <div class="images-container" (mouseenter)="pauseAutoPlay()" (mouseleave)="startAutoPlay()" #slideImg>
                  <ng-template slideZone>

                  </ng-template>
              </div>

          </div>
          <div class="dots-container">
              <ul (mouseenter)="pauseAutoPlay()" (mouseleave)="startAutoPlay()">
                  <li *ngFor="let dot of slides;let i = index;" (click)="slideToIndex(i)" [ngClass]="{selected: i == index}">
                      <img src="assets/img/buttons/dot.svg" alt="dot">
                  </li>
              </ul>
          </div>
          <div class="arrow right-arrow" (click)="slideForward()" (mouseenter)="pauseAutoPlay()">
              <img src="assets/img/buttons/arrow-right-v2.svg">
          </div>
      </div>
    `,
                styles: [`
      .carousel-container {
          width: 100%;
          max-height: 100vh;
          overflow: hidden;
          position: relative;

      }

      .images-container {
          width: 100%;
          display: -ms-flexbox;
          display: -webkit-box;
          display: flex;
          -ms-flex: 1;
          -webkit-box-flex: 1;
                  flex: 1;
          -ms-flex-align: center;
          -webkit-box-align: center;
                  align-items: center;
          -ms-flex-pack: start;
          -webkit-box-pack: start;
                  justify-content: flex-start;
          -webkit-transition: all 300ms cubic-bezier(0.35, 0, 0.25, 1);
          transition: all 300ms cubic-bezier(0.35, 0, 0.25, 1);
      }

      .carousel-container .arrow {
          z-index: 2;
          position: absolute;
          top: 0;
          height: 100%;
          width: 4%;
          display: -ms-flexbox;
          display: -webkit-box;
          display: flex;
          -ms-flex-direction: row;
          -webkit-box-orient: horizontal;
          -webkit-box-direction: normal;
                  flex-direction: row;
          -ms-flex-wrap: nowrap;
          flex-wrap: nowrap;
          -ms-flex-pack: center;
          -webkit-box-pack: center;
                  justify-content: center;
          -ms-flex-line-pack: stretch;
          align-content: stretch;
          -ms-flex-align: center;
          -webkit-box-align: center;
                  align-items: center;

      }

      .carousel-container .arrow img {
          width: 100%;
          -ms-flex-order: 0;
          -webkit-box-ordinal-group: 1;
                  order: 0;
          -ms-flex: 0 1 auto;
          -webkit-box-flex: 0;
                  flex: 0 1 auto;
          -webkit-align-self: auto;
          -ms-flex-item-align: auto;
          align-self: auto;
      }

      .carousel-container .left-arrow {
          -webkit-transition: all .6s ease-out;
          transition: all .6s ease-out;
          left: 0;
          cursor: pointer;
      }

      .carousel-container .right-arrow {
          right: 0;
          cursor: pointer;
      }

      /*
      .carousel-container .left-arrow:hover {
      	background: -moz-linear-gradient(left, rgba(0, 0, 0, 0.65) 0%, rgba(0, 0, 0, 0) 100%); !* FF3.6-15 *!
      	background: -webkit-linear-gradient(left, rgba(0, 0, 0, 0.65) 0%, rgba(0, 0, 0, 0) 100%); !* Chrome10-25,Safari5.1-6 *!
      	background: linear-gradient(to right, rgba(0, 0, 0, 0.65) 0%, rgba(0, 0, 0, 0) 100%); !* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ *!
      	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#a6000000', endColorstr='#00000000', GradientType=1); !* IE6-9 *!
      }

      .carousel-container .right-arrow:hover {
      	background: -moz-linear-gradient(left, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.65) 100%); !* FF3.6-15 *!
      	background: -webkit-linear-gradient(left, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.65) 100%); !* Chrome10-25,Safari5.1-6 *!
      	background: linear-gradient(to right, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.65) 100%); !* W3C, IE10+, FF16+, Chrome26+, Opera12+, Safari7+ *!
      	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#a6000000', GradientType=1); !* IE6-9 *!
      }*/

      .carousel-container .dots-container {
          z-index: 2;
          position: absolute;
          bottom: 0;
          height: 10%;
          width: 100%;
          display: -ms-flexbox;
          display: -webkit-box;
          display: flex;
          -ms-flex-direction: row;
          -webkit-box-orient: horizontal;
          -webkit-box-direction: normal;
                  flex-direction: row;
          -ms-flex-wrap: nowrap;
          flex-wrap: nowrap;
          -ms-flex-pack: center;
          -webkit-box-pack: center;
                  justify-content: center;
          -ms-flex-line-pack: stretch;
          align-content: stretch;
          -ms-flex-align: center;
          -webkit-box-align: center;
                  align-items: center;
      }

      .carousel-container .dots-container ul {
          list-style-type: none;
          margin: 0;
          padding: 0;
          overflow: hidden;
      }

      .carousel-container .dots-container ul li {
          display: inline;
      }

      .carousel-container .dots-container ul li img {
          width: 10px;
          padding: 5px;
      }

      .carousel-container .dots-container img {
          cursor: pointer;
          height: 10%;
          width: 100%;
          -ms-flex-order: 0;
          -webkit-box-ordinal-group: 1;
                  order: 0;
          -ms-flex: 0 1 auto;
          -webkit-box-flex: 0;
                  flex: 0 1 auto;
          -webkit-align-self: auto;
          -ms-flex-item-align: auto;
          align-self: auto;
          opacity: .5;
          /*transition: all .7s ease-out;*/
      }

      .carousel-container .dots-container li.selected img {
          opacity: 1;
      }
    `]
            },] },
];
/**
 * @nocollapse
 */
CarouselComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver, },
];
CarouselComponent.propDecorators = {
    'autoPlay': [{ type: Input },],
    'time': [{ type: Input },],
    'slidesZone': [{ type: ViewChild, args: ['slidesZone',] },],
    'sliderContainer': [{ type: ViewChild, args: ['sliderContainer',] },],
    'slideZone': [{ type: ViewChild, args: [SlideZoneDirective,] },],
};

class CarouselItemComponent {
    /**
     * @param {?} parent
     */
    constructor(parent) {
        this.parent = parent;
        parent.addSlideData(this);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.parent.removeSlide(this);
    }
}
CarouselItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'pac-item',
                template: `

    `,
                styles: [`

    `]
            },] },
];
/**
 * @nocollapse
 */
CarouselItemComponent.ctorParameters = () => [
    { type: CarouselComponent, },
];
CarouselItemComponent.propDecorators = {
    'src': [{ type: Input },],
    'link': [{ type: Input },],
    'route': [{ type: Input },],
};

class PacSliderModule {
}
PacSliderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    RouterModule
                ],
                declarations: [CarouselComponent, CarouselItemComponent, CarouselSlideComponent, SlideZoneDirective],
                entryComponents: [CarouselSlideComponent],
                exports: [CarouselComponent, CarouselItemComponent]
            },] },
];
/**
 * @nocollapse
 */
PacSliderModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { PacSliderModule, CarouselItemComponent as ɵc, CarouselSlideComponent as ɵd, CarouselComponent as ɵa, SlideZoneDirective as ɵb };
//# sourceMappingURL=pac-slider.js.map
